@@ -22,7 +22,7 @@ class ClusterRole(Resource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.rules:
                 raise MissingRequiredArgumentError(argument="rules")
             self.res["rules"] = self.rules
