@@ -1,18 +1,13 @@
 import pytest
-from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.kube_descheduler import KubeDescheduler
 
 
 @pytest.mark.incremental
 class TestKubeDescheduler:
     @pytest.fixture(scope="class")
-    def client(self):
-        return FakeDynamicClient()
-
-    @pytest.fixture(scope="class")
-    def kubedescheduler(self, client):
+    def kubedescheduler(self, fake_client):
         return KubeDescheduler(
-            client=client,
+            client=fake_client,
             name="test-kubedescheduler",
             namespace="default",
         )
